@@ -8,8 +8,8 @@ class CoverageArticle(AbstractArticle):
     """
     dynamic_fields_names = (
         "tipusVia", "nomVia", "numero", "bloc", "portal", "pis", "escala", "porta",
-        "poblacioServei", "provinciaServei", "CPservei", "altresCobertura", "coberturaADSL",
-        "coberturaFibraMM", "coberturaFibraVdf", "IDhogar"
+        "poblacioServei", "provinciaServei", "codiProvinciaServei", "CPservei", "altresCobertura",
+        "coberturaADSL", "coberturaFibraMM", "coberturaFibraVdf", "IDhogar"
     )
     subject = "Sol·licitud cobertura"
 
