@@ -3,7 +3,7 @@ class FiberData:
 
     def __init__(
         self, order_id, phone_number, iban, service_address, service_city,
-        service_zip, service_subdivision, shipment_address, shipment_city, shipment_zip,
+        service_zip, service_subdivision, service_subdivision_code, shipment_address, shipment_city, shipment_zip,
         shipment_subdivision, previous_service, previous_provider, previous_internal_provider,
         previous_owner_vat, previous_owner_name, previous_owner_surname, notes,
             adsl_coverage, mm_fiber_coverage, vdf_fiber_coverage, change_address, product):
@@ -22,6 +22,7 @@ class FiberData:
         self.service_city = service_city
         self.service_zip = service_zip
         self.service_subdivision = service_subdivision
+        self.service_subdivision_code = service_subdivision_code
         self.shipment_address = shipment_address
         self.shipment_city = shipment_city
         self.shipment_zip = shipment_zip
