@@ -45,6 +45,6 @@ class UpdateTicketWithCoverageTicketInfoTestCase(unittest.TestCase):
         MockClient.return_value.ticket_update.assert_called_with(ticket_id, coverage_article, dynamic_fields=[])
         MockArticle.assert_called_with({
             "Subject": "Sol·licitud cobertura",
-            "Body": "tipusVia: foo\nnomVia: foo\nnumero: foo\nbloc: foo\nportal: foo\npis: foo\nescala: foo\nporta: foo\npoblacioServei: foo\nprovinciaServei: foo\nCPservei: foo\naltresCobertura: foo\ncoberturaADSL: foo\ncoberturaFibraMM: foo\ncoberturaFibraVdf: foo\nIDhogar: foo\n",  # noqa
+            "Body": "tipusVia: foo\nnomVia: foo\nnumero: foo\nbloc: foo\nportal: foo\npis: foo\nescala: foo\nporta: foo\npoblacioServei: foo\nprovinciaServei: foo\ncodiProvinciaServei: foo\nCPservei: foo\naltresCobertura: foo\ncoberturaADSL: foo\ncoberturaFibraMM: foo\ncoberturaFibraVdf: foo\nIDhogar: foo\n",  # noqa
             "ContentType": "text/plain; charset=utf8"
         })
