@@ -69,6 +69,7 @@ class OTRSTicketResponseTestCase(unittest.TestCase):
             {"Name": "direccioServei", "Value": "Street 1234"},
             {"Name": "poblacioServei", "Value": "Barcelona"},
             {"Name": "provinciaServei", "Value": "Barcelona"},
+            {"Name": "codiProvinciaServei", "Value": "ES-B"},
             {"Name": "CPservei", "Value": "08123"},
             {"Name": "IDcomanda", "Value": "1234"},
             {"Name": "IDhogar", "Value": None},
@@ -99,6 +100,7 @@ class OTRSTicketResponseTestCase(unittest.TestCase):
         self.assertEqual("Street 1234", ticket.service_address)
         self.assertEqual("Barcelona", ticket.service_city)
         self.assertEqual("Barcelona", ticket.service_subdivision)
+        self.assertEqual("ES-B", ticket.service_subdivision_code)
         self.assertEqual("08123", ticket.service_zip)
         self.assertEqual("1234", ticket.extid)
         self.assertEqual("1907", ticket.reference)
