@@ -19,7 +19,8 @@ class ADSLDataTestCase(unittest.TestCase):
             service_address="address",
             service_city="city",
             service_zip="08001",
-            service_subdivision="ES-B",
+            service_subdivision="Barcelona",
+            service_subdivision_code="ES-B",
             shipment_address="address",
             shipment_city="city",
             shipment_zip="08001",
