@@ -34,6 +34,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             'service_city',
             'service_zip',
             'service_subdivision',
+            'service_subdivision_code',
             'shipment_address',
             'shipment_city',
             'shipment_zip',
@@ -259,6 +260,19 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["provinciaServei"], "Subdivision")
 
+    def test_service_subdivision_code_field(self):
+        self.service_data.service_subdivision_code = "ES-B"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["codiProvinciaServei"], "ES-B")
+
     def test_shipment_address_field(self):
         self.service_data.shipment_address = "Street"
 
